package overflow_grpc_pool

import (
	"log"
	"time"

	"google.golang.org/grpc"
)

const (
	// DefaultWriteTimeout is default value of Write Timeout
	DefaultIdleTimeout = 0
)

type (
	CreateFunc func() (*grpc.ClientConn, interface{}, error)
)

// Options is configuration of the Pool of GRpc client
type Options struct {
	Creators CreateFunc

	IdleTimeout time.Duration
	MaxIdle     int
	MaxCapacity int
}

// Validate validates the configuration
func (o *Options) Validate() *Options {
	if o.IdleTimeout < 0 {
		o.IdleTimeout = DefaultIdleTimeout
	}
	if o.MaxIdle < 0 {
		o.MaxIdle = 0
	}
	if o.MaxCapacity <= 0 {
		log.Panicln("Max capacity of Pool must be greater than 0.")
	}
	if o.Creators == nil {
		log.Panicln("Creators of Pool must be specified.")
	}

	return o
}
